@@ -171,8 +171,8 @@ class Spectrum(EmissionFitting, LiMePlots, LineFinder):
         self._emission_check = emission
         self._cont_from_adjacent = adjacent_cont
 
-         # Establish spectrum line and continua regions
-        idcsEmis, idcsCont = self.define_masks(self.wave_rest, self.flux, self.mask)
+        # Get spectrum line and continua band indeces
+        idcsEmis, idcsCont = self.define_masks(self.wave, self.mask*(1 + self.redshift), line_mask_entry=fit_conf.get(f'{self.line}_mask'))
 
         # Integrated line properties
         emisWave, emisFlux = self.wave[idcsEmis], self.flux[idcsEmis]
@@ -202,8 +202,7 @@ class Spectrum(EmissionFitting, LiMePlots, LineFinder):
         idcsLine = idcsEmis + idcsCont
         x_array = self.wave[idcsLine]
         y_array = self.flux[idcsLine]
-        w_array = 1.0 / self.err_flux[idcsLine] if self.err_flux is not None else np.full(x_array.size,
-                                                                                          1.0 / self.std_cont)
+        w_array = 1.0 / self.err_flux[idcsLine] if self.err_flux is not None else np.full(x_array.size, 1.0 / self.std_cont)
         self.gauss_lmfit(self.line, x_array, y_array, w_array, fit_conf, self.log, z_obj=self.redshift)
 
         # Safe the results to log DF
@@ -414,7 +413,7 @@ class Spectrum(EmissionFitting, LiMePlots, LineFinder):
 class MaskInspector(Spectrum):
 
     def __init__(self, log_address, input_wave=None, input_flux=None, input_err=None, redshift=0,
-                 norm_flux=1.0, crop_waves=None, n_cols=10, n_rows=None, lines_interval=None):
+                 norm_flux=1.0, crop_waves=None, n_cols=10, n_rows=None, lines_interval=None, y_scale='auto'):
 
         """
         This class plots the masks from the ``log_address`` as a grid for the input spectrum as a grid. Clicking and
@@ -439,6 +438,9 @@ class MaskInspector(Spectrum):
         parameter can be an array of strings with the labels of the target lines or a two value integer array with the
         interval of lines to plot.
 
+        Lines in the mask file outside the spectral wavelength range will be excluded from the plot: w2 abd w5 smaller
+        and greater than the blue and red wavelegnth values respectively.
+
         :param log_address: Address for the lines log mask file.
         :type log_address: str
 
@@ -469,10 +471,16 @@ class MaskInspector(Spectrum):
         :param lines_interval: List of lines or mask file line interval to display on the grid plot. In the later case
                                this interval must be a two value array.
         :type lines_interval: list
+
+        :param y_scale: Y axis scale. The default value (auto) will switch between between linear and logarithmic scale
+                        strong and weak lines respectively. Use ``linear`` and ``log`` for a fixed scale for all lines.
+        :type y_scale: str, optional
+
         """
 
         # Output file address
         self.linesLogAddress = Path(log_address)
+        self.y_scale = y_scale
 
         # Assign attributes to the parent class
         super().__init__(input_wave, input_flux, input_err, redshift, norm_flux, crop_waves)
@@ -521,20 +529,20 @@ class MaskInspector(Spectrum):
         with rc_context(PLOT_CONF):
 
             self.fig, ax = plt.subplots(nrows=n_rows, ncols=n_cols)
-            self.ax = ax.flatten()
+            self.ax = ax.flatten() if n_lines > 1 else [ax]
             self.in_ax = None
             self.dict_spanSelec = {}
             self.axConf = {}
 
             # Plot function
-            self.plot_line_mask_selection(logscale='auto', grid_size=n_rows * n_cols)
+            self.plot_line_mask_selection(logscale=self.y_scale, grid_size=n_rows * n_cols)
             plt.gca().axes.yaxis.set_ticklabels([])
 
             try:
                 manager = plt.get_current_fig_manager()
                 manager.window.showMaximized()
-            except:
-                print('-- Window could not be maximized')
+            except: #TODO add exception
+                print()
 
             plt.tight_layout()
             plt.show()
@@ -649,6 +657,10 @@ class MaskInspector(Spectrum):
         if logscale == 'auto':
             if fluxPeak[idxPeakFlux] > 5 * np.median(fluxLine):
                 ax.set_yscale('log')
+        else:
+            if logscale == 'log':
+                ax.set_yscale('log')
+
 
         return
 
@@ -731,7 +743,7 @@ class MaskInspector(Spectrum):
 
             # Redraw the line measurement
             self.in_ax.clear()
-            self.plot_line_region_i(self.in_ax, self.line, logscale='auto')
+            self.plot_line_region_i(self.in_ax, self.line, logscale=self.y_scale)
             self.in_fig.canvas.draw()
 
         return
@@ -1021,11 +1033,11 @@ class CubeInspector(Spectrum):
                 line_list = self.log.index.values
 
                 # Reference frame for the plot
-                wave_plot, flux_plot, z_corr, mask_corr = self.plot_frame_switch(self.wave, flux_voxel, self.redshift, frame)
+                wave_plot, flux_plot, z_corr, idcs_mask = self.frame_mask_switch(self.wave, flux_voxel, self.redshift, frame)
 
                 # Compute the individual profiles
-                wave_array, gaussian_array = gaussian_profiles_computation(line_list, self.log, z_corr, mask_corr)
-                wave_array, cont_array = linear_continuum_computation(line_list, self.log, z_corr, mask_corr)
+                wave_array, gaussian_array = gaussian_profiles_computation(line_list, self.log, (1 + self.redshift))
+                wave_array, cont_array = linear_continuum_computation(line_list, self.log, (1 + self.redshift))
 
                 # Mask with
                 w3_array, w4_array = self.log.w3.values, self.log.w4.values
@@ -1033,15 +1045,16 @@ class CubeInspector(Spectrum):
                 # Separating blended from unblended lines
                 idcs_nonBlended = (self.log.index.str.endswith('_m')) | (self.log.profile_label == 'no').values
 
+                w3 = self.log.w3.values * (1 + self.redshift)
+                w4 = self.log.w4.values * (1 + self.redshift)
+                idcsLines = ((w3 - 5) <= wave_plot[:, None]) & (wave_plot[:, None] <= (w4 + 5))
+
                 # Plot single lines
                 line_list = self.log.loc[idcs_nonBlended].index
                 for line in line_list:
 
                     i = self.log.index.get_loc(line)
 
-                    # Determine the line region
-                    idcs_plot = ((w3_array[i] - 5) * mask_corr <= wave_plot) & (wave_plot <= (w4_array[i] + 5) * mask_corr)
-
                     # Plot the gauss curve elements
                     wave_i = wave_array[:, i][..., None]
                     cont_i = cont_array[:, i][..., None]
@@ -1049,7 +1062,7 @@ class CubeInspector(Spectrum):
 
                     line_comps = [line]
                     self.gaussian_profiles_plotting(line_comps, self.log,
-                                                    wave_plot[idcs_plot], flux_plot[idcs_plot], z_corr,
+                                                    wave_plot[idcsLines[:, i]], flux_plot[idcsLines[:, i]], z_corr,
                                                     axis=self.ax1, frame=frame, cont_bands=None,
                                                     wave_array=wave_i, cont_array=cont_i,
                                                     gaussian_array=gauss_i)
@@ -1062,7 +1075,7 @@ class CubeInspector(Spectrum):
                     i_group = np.where(idcs_group)[0]
 
                     # Determine the line region
-                    idcs_plot = ((w3_array[i_group[0]] - 1) * mask_corr <= wave_plot) & (wave_plot <= (w4_array[i_group[0]] + 1) * mask_corr)
+                    idcs_plot = ((w3[i_group[0]] - 1) <= wave_plot) & (wave_plot <= (w4[i_group[0]] + 1))
 
                     # Plot the gauss curve elements
                     wave_i = wave_array[:, i_group[0]:i_group[-1]+1]
